diario_retrieve_token: Retrieve the API token for Diario

View source: R/diario.R

diario_retrieve_tokenR Documentation

Retrieve the API token for Diario

Description

This function retrieves the stored authentication token using the keyring package. If no valid token (or keyring) is found, it will return NULL and emit an informational message indicating that no valid token was found.

Usage

diario_retrieve_token()

Value

A character string containing the API token, or NULL if no valid token is found.

Examples

## Not run: 
token <- diario_retrieve_token()

## End(Not run)

diario documentation built on April 27, 2026, 9:09 a.m.