| diario_store_token | R Documentation |
This function stores the provided authentication token using the keyring package.
If the token cannot be stored (for example, because the keyring is not accessible),
it emits a warning instead of throwing an error, and returns FALSE.
diario_store_token(token)
token |
A character string containing the API token to be stored. |
TRUE (invisibly) if the token was stored successfully;
FALSE otherwise.
## Not run:
# Attempt to store a token:
diario_store_token("your-api-token")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.