| diario_retrieve_token | R Documentation |
This function retrieves the stored authentication token using the keyring package.
If no valid token (or keyring) is found, it will return NULL and emit an
informational message indicating that no valid token was found.
diario_retrieve_token()
A character string containing the API token, or NULL if no valid token is found.
## Not run:
token <- diario_retrieve_token()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.