This function retrieves the stored authentication token using the keyring package.
If no valid token (or keyring) is found, it will return NULL and emit an
informational message indicating that no valid token was found.
This function retrieves the stored authentication token using the keyring package.
If no valid token (or keyring) is found, it will return NULL and emit an
informational message indicating that no valid token was found.