This function stores the provided authentication token using the keyring package.
If the token cannot be stored (for example, because the keyring is not accessible),
it emits a warning instead of throwing an error, and returns FALSE.
This function stores the provided authentication token using the keyring package.
If the token cannot be stored (for example, because the keyring is not accessible),
it emits a warning instead of throwing an error, and returns FALSE.